David Wu has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/47351 )
Change subject: mb/google/volteer/var/voema: Add memory parts and generate DRAM IDs
......................................................................
mb/google/volteer/var/voema: Add memory parts and generate DRAM IDs
This change adds memory parts used by variant voema to
mem_parts_used.txt and generates DRAM IDs allocated to these parts.
Added memory
1. H9HCNNNCRMBLPR-NEE
2. H9HCNNNFBMBLPR-NEE
3. MT53D1G64D4NW-046 WT:A
BUG=b:172751925
TEST=emerge-volteer coreboot chromeos-bootimage
Signed-off-by: David Wu <david_wu(a)quanta.corp-partner.google.com>
Change-Id: Ic832155448fb07152b906aa04ca49d384ec47b34
---
M src/mainboard/google/volteer/variants/voema/memory/Makefile.inc
M src/mainboard/google/volteer/variants/voema/memory/dram_id.generated.txt
M src/mainboard/google/volteer/variants/voema/memory/mem_parts_used.txt
3 files changed, 9 insertions(+), 2 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/51/47351/1
diff --git a/src/mainboard/google/volteer/variants/voema/memory/Makefile.inc b/src/mainboard/google/volteer/variants/voema/memory/Makefile.inc
index 3c8ea48..7b69aa4 100644
--- a/src/mainboard/google/volteer/variants/voema/memory/Makefile.inc
+++ b/src/mainboard/google/volteer/variants/voema/memory/Makefile.inc
@@ -2,5 +2,6 @@
## This is an auto-generated file. Do not edit!!
SPD_SOURCES =
-SPD_SOURCES += lp4x-spd-1.hex # ID = 0(0b0000) Parts = MT53E512M64D4NW-046 WT:E
-SPD_SOURCES += lp4x-spd-3.hex # ID = 1(0b0001) Parts = MT53E1G64D8NW-046 WT:E
+SPD_SOURCES += lp4x-spd-1.hex # ID = 0(0b0000) Parts = MT53E512M64D4NW-046 WT:E, H9HCNNNCRMBLPR-NEE
+SPD_SOURCES += lp4x-spd-3.hex # ID = 1(0b0001) Parts = MT53E1G64D8NW-046 WT:E, H9HCNNNFBMBLPR-NEE
+SPD_SOURCES += lp4x-spd-4.hex # ID = 2(0b0010) Parts = MT53D1G64D4NW-046 WT:A
diff --git a/src/mainboard/google/volteer/variants/voema/memory/dram_id.generated.txt b/src/mainboard/google/volteer/variants/voema/memory/dram_id.generated.txt
index 02e7443..840f71a 100644
--- a/src/mainboard/google/volteer/variants/voema/memory/dram_id.generated.txt
+++ b/src/mainboard/google/volteer/variants/voema/memory/dram_id.generated.txt
@@ -1,3 +1,6 @@
DRAM Part Name ID to assign
MT53E512M64D4NW-046 WT:E 0 (0000)
MT53E1G64D8NW-046 WT:E 1 (0001)
+H9HCNNNCRMBLPR-NEE 0 (0000)
+H9HCNNNFBMBLPR-NEE 1 (0001)
+MT53D1G64D4NW-046 WT:A 2 (0010)
diff --git a/src/mainboard/google/volteer/variants/voema/memory/mem_parts_used.txt b/src/mainboard/google/volteer/variants/voema/memory/mem_parts_used.txt
index b74da4a..c74fe43 100644
--- a/src/mainboard/google/volteer/variants/voema/memory/mem_parts_used.txt
+++ b/src/mainboard/google/volteer/variants/voema/memory/mem_parts_used.txt
@@ -1,2 +1,5 @@
MT53E512M64D4NW-046 WT:E
MT53E1G64D8NW-046 WT:E
+H9HCNNNCRMBLPR-NEE
+H9HCNNNFBMBLPR-NEE
+MT53D1G64D4NW-046 WT:A
--
To view, visit https://review.coreboot.org/c/coreboot/+/47351
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: Ic832155448fb07152b906aa04ca49d384ec47b34
Gerrit-Change-Number: 47351
Gerrit-PatchSet: 1
Gerrit-Owner: David Wu <david_wu(a)quanta.corp-partner.google.com>
Gerrit-Reviewer: Martin Roth <martinroth(a)google.com>
Gerrit-Reviewer: Patrick Georgi <pgeorgi(a)google.com>
Gerrit-MessageType: newchange
Kangheui Won has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/47360 )
Change subject: drivers/i2c/dw: Check for TX_ABORT in transfer
......................................................................
drivers/i2c/dw: Check for TX_ABORT in transfer
When the host sends data in i2c bus, device might not send ACK. It means
that data is not processed on the device side, but for now we don't
check for that condition thus wait for the response which will not come.
Designware i2c detect such situation and set TX_ABORT bit. Checking for
the bit will enable other layers to immediately retry rather than
wait-timeout-retry cycle.
BUG=b:168838505
BRANCH=zork
TEST=test on zork devices, now we see "Tx abort detected" instead of I2C
timeout for tpm initializtion.
Change-Id: Ib0163fbce55ccc99f677dbb096f67a58d2ef2bda
---
M src/drivers/i2c/designware/dw_i2c.c
1 file changed, 10 insertions(+), 2 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/60/47360/1
diff --git a/src/drivers/i2c/designware/dw_i2c.c b/src/drivers/i2c/designware/dw_i2c.c
index 3181e7a..5601bcf 100644
--- a/src/drivers/i2c/designware/dw_i2c.c
+++ b/src/drivers/i2c/designware/dw_i2c.c
@@ -419,6 +419,14 @@
/* Read to clear INTR_STAT_STOP_DET */
read32(®s->clear_stop_det_intr);
+ /* Check TX abort */
+ if (read32(®s->raw_intr_stat) & INTR_STAT_TX_ABORT) {
+ printk(BIOS_ERR, "I2C TX abort detected\n");
+ /* clear INTR_STAT_TX_ABORT */
+ read32(®s->clear_tx_abrt_intr);
+ goto out;
+ }
+
/* Wait for the bus to go idle */
if (dw_i2c_wait_for_bus_idle(regs)) {
printk(BIOS_ERR, "I2C timeout waiting for bus %u idle\n", bus);
@@ -747,8 +755,8 @@
write32(®s->rx_thresh, 0);
write32(®s->tx_thresh, 0);
- /* Enable stop detection interrupt */
- write32(®s->intr_mask, INTR_STAT_STOP_DET);
+ /* Enable stop detection and TX abort interrupt */
+ write32(®s->intr_mask, INTR_STAT_STOP_DET | INTR_STAT_TX_ABORT);
printk(BIOS_INFO, "DW I2C bus %u at %p (%u KHz)\n",
bus, regs, speed / KHz);
--
To view, visit https://review.coreboot.org/c/coreboot/+/47360
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: Ib0163fbce55ccc99f677dbb096f67a58d2ef2bda
Gerrit-Change-Number: 47360
Gerrit-PatchSet: 1
Gerrit-Owner: Kangheui Won <khwon(a)chromium.org>
Gerrit-MessageType: newchange